<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" xmlns:xrndm="http://xmlreleasenotes.free.fr/plugin/DependencyModel" version="1.0">
	<!--
	This file belongs to XMLReleaseNotes V@XRN_VERSION@.
	-->
	<!--
	The aim of this model XSLT is to integrate the release notes of the component-dependencies of a component into its release notes.
	This concerns both the 'Composition', the 'Dependencies' and the 'Requirements' information.
	This enables to inline other components release notes into the component that refers to them.
	-->
	<xsl:import href="XRNModelCommon.xsl"/>
	<xsl:import href="XMLReleaseNotesCommon.xsl"/>
	<xsl:output method="xml" indent="yes"/>
	<!--
	Indicates whether the composition release notes should be inlined or not.
	-->
	<xsl:param name="composition" select="true()"/>
	<!--
	Indicates whether the dependencies release notes should be inlined or not.
	-->
	<xsl:param name="dependency" select="false()"/>
	<!--
	Indicates whether the rquirements release notes should be inlined or not.
	-->
	<xsl:param name="requirement" select="false()"/>
	<xsl:template match="xrn:ReleaseNotes/Releases/Release">
		<xsl:choose>
			<xsl:when test="not(Features)">
				<Release>
					<xsl:copy-of select="@*"/>
					<xsl:copy-of select="*"/>
					<Features>
						<xsl:if test="$composition">
							<xsl:for-each select="*[name() = 'Composition']/Component">
								<xsl:call-template name="_printComponentFeatures">
									<xsl:with-param name="blockName" select="'Composition'"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="$dependency">
							<xsl:for-each select="*[name() = 'Dependencies']/Component">
								<xsl:call-template name="_printComponentFeatures">
									<xsl:with-param name="blockName" select="'Dependencies'"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="$requirement">
							<xsl:for-each select="*[name() = 'Requirements']/Component">
								<xsl:call-template name="_printComponentFeatures">
									<xsl:with-param name="blockName" select="'Requirements'"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
					</Features>
				</Release>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:copy-of select="@*"/>
					<xsl:apply-templates/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases/Release/Features">
		<xsl:if test="$composition">
			<xsl:call-template name="_printBlock2">
				<xsl:with-param name="blockName" select="'Composition'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$dependency">
			<xsl:call-template name="_printBlock2">
				<xsl:with-param name="blockName" select="'Dependencies'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$requirement">
			<xsl:call-template name="_printBlock2">
				<xsl:with-param name="blockName" select="'Requirements'"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printBlock2">
		<xsl:param name="blockName"/>
		<Features>
			<xsl:copy-of select="@*"/>
			<xsl:copy-of select="*"/>
			<xsl:if test="../*[name() = $blockName]">
				<xsl:for-each select="../*[name() = $blockName]/Component">
					<xsl:call-template name="_printComponentFeatures">
						<xsl:with-param name="blockName" select="$blockName"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:if>
		</Features>
	</xsl:template>
	<!--
	The current node is supposed to be a 'Release/[Composition|Dependencies|Requirements]/Component' XML element.
	-->
	<xsl:template name="_printComponentFeatures">
		<xsl:param name="blockName"/>
		<xsl:variable name="componentID" select="@ID"/>
		<xsl:variable name="componentVersion" select="@version"/>
		<xsl:if test="../../../../Components/Component[@ID = $componentID]/@xml">
			<xsl:for-each select="document(../../../../Components/Component[@ID = $componentID]/@xml)/xrn:ReleaseNotes/Releases/Release[@version = $componentVersion]/Features/Feature">
				<xsl:variable name="inline">
					<xsl:choose>
						<xsl:when test="$blockName = 'Composition'">
							<xsl:value-of select="count(Tags/xrndm:export[@composition and @composition = 'false']) = 0"/>
						</xsl:when>
						<xsl:when test="$blockName = 'Dependencies'">
							<xsl:value-of select="count(Tags/xrndm:export[@dependency and @dependency = 'true']) = 1"/>
						</xsl:when>
						<xsl:when test="$blockName = 'Requirements'">
							<xsl:value-of select="count(Tags/xrndm:export[@requirement and @requirement = 'true']) = 1"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:if test="$inline = 'true'">
					<Feature>
						<xsl:attribute name="ID"><xsl:value-of select="$componentID"/> - <xsl:value-of select="@ID"/></xsl:attribute>
						<xsl:copy-of select="@*[name() != @ID]"/>
						<xsl:copy-of select="*"/>
					</Feature>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
